Coverage report

File | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/optwps/__init__.py | 8 | 2 | 0 | 0 | 0 | 75%
src/optwps/optwps.py | 201 | 32 | 0 | 70 | 9 | 84%
src/optwps/utils.py | 23 | 2 | 0 | 6 | 1 | 90%
tests/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests/conftest.py | 63 | 0 | 0 | 6 | 0 | 100%
tests/test_multiple_outputs.py | 86 | 0 | 0 | 18 | 1 | 99%
tests/test_optwps.py | 147 | 9 | 0 | 46 | 11 | 90%
Total | 528 | 45 | 0 | 146 | 22 | 90%

No items found using the specified filter.